<?php
/**
 * Style template.
 *
 * 🚫🚫🚫
 * DO NOT EDIT THIS FILE WHILE INSIDE THE PLUGIN! Changes You make will be lost when a new version
 * of the AMP plugin is released. You need to copy this file out of the plugin and put it into your
 * custom theme, for example. To learn about how to customize these Reader-mode AMP templates, please
 * see: https://amp-wp.org/documentation/how-the-plugin-works/classic-templates/
 * 🚫🚫🚫
 *
 * @package AMP
 */

// phpcs:disable WordPress.Security.EscapeOutput.OutputNotEscaped

/**
 * Context.
 *
 * @var AMP_Post_Template $this
 */

$customizer_settings = mura_general_settings();

$primary_theme_color = get_theme_mod( 'mura_primary_theme_color', $customizer_settings['primary_theme_color'] );
$black = '#000000';
$white = '#ffffff';
$off_white = '#f7f8fa';
$muted_text_color = '#94979e';

$content_max_width       = absint( $this->get( 'content_max_width' ) );

$theme_color             = $this->get_customizer_setting( 'theme_color' );
$text_color              = $this->get_customizer_setting( 'text_color' );
$border_color            = $this->get_customizer_setting( 'border_color' );
$link_color              = get_theme_mod( 'mura_link_color', '' );
$header_background_color = '' === get_theme_mod( 'mura_header_background_color', '' ) ? $white : get_theme_mod( 'mura_header_background_color', '' );
$header_color            = '' === get_theme_mod( 'mura_header_logo_color', '' ) ? $black : get_theme_mod( 'mura_header_logo_color', '' );
$header_toggle_color     = '' === get_theme_mod( 'mura_header_toggle_icon_color', '' ) ? $black : get_theme_mod( 'mura_header_toggle_icon_color', '' );
$footer_background 		 = '' === get_theme_mod( 'mura_footer_background', '' ) ? $off_white : get_theme_mod( 'mura_footer_background', '' );
$button_color            = '' === get_theme_mod( 'mura_button_color', '' ) ? $white : get_theme_mod( 'mura_button_color', '' );
$button_background       = '' === get_theme_mod( 'mura_button_background', '' ) ? $primary_theme_color  : get_theme_mod( 'mura_button_background', '' );
$logo_width = get_theme_mod( 'mura_custom_logo_max_width_mobile', 100 );
$logo_width_small = get_theme_mod( 'mura_custom_logo_max_width_small', 70 );
$toggle_sidebar_background = '' === get_theme_mod( 'mura_toggle_sidebar_background', '' ) ? $white  : get_theme_mod( 'mura_toggle_sidebar_background', '' );
$toggle_sidebar_menu_color = '' === get_theme_mod( 'mura_toggle_sidebar_menu_color', '' ) ? $black  : get_theme_mod( 'mura_toggle_sidebar_menu_color', '' );

$alignwide_max = $content_max_width > 0 ? $content_max_width * 2 : 1920

?>
/* Generic WP styling */

.alignnone,
.aligncenter,
.alignleft,
.alignright,
.alignwide {
	margin-top: 1em;
	margin-right: auto;
	margin-bottom: 1em;
	margin-left: auto;
}

.alignright {
	float: right;
}

.alignleft {
	float: left;
}
@media (max-width: 480px) {
	.alignleft,
	.alignright {
		width: 100%;
		margin-left: auto;
		margin-right: auto;
	}
}
.aligncenter {
	display: block;
	text-align: center;
	margin-left: auto;
	margin-right: auto;
}

.alignwide {
	width: 100%;
}

@media (min-width: 792px) {
	.alignwide {
		width: calc(100vw - 48px);
		max-width: calc(100vw - 48px);
		margin-left: calc(50% - 50vw + 24px);
		margin-right: calc(50% - 50vw + 24px);
	}
}

@media (min-width: <?php echo sprintf( '%dpx', $alignwide_max ); ?>) {
	.alignwide {
		width: calc(<?php echo sprintf( '%dpx', $alignwide_max ); ?> - 48px);
		max-width: calc(<?php echo sprintf( '%dpx', $alignwide_max ); ?> - 48px);
		margin-left: calc(calc(50% - <?php echo sprintf( '%dpx', $alignwide_max ); ?> / 2) + 24px);
		margin-right: calc(calc(50% - <?php echo sprintf( '%dpx', $alignwide_max ); ?> / 2) + 24px);
	}
}

.alignfull {
	width: 100vw;
	max-width: 100vw;
	margin-left: calc(50% - 50vw);
	margin-right: calc(50% - 50vw);
}

.amp-wp-enforced-sizes {
	/** Our sizes fallback is 100vw, and we have a padding on the container; the max-width here prevents the element from overflowing. **/
	max-width: 100%;
	width:100%;
	margin: 0 auto;
}

/* Headings */

h1 {
	font-size: 2.5rem;
	line-height:1.2;
}

h2 {
	font-size: 2rem;
	line-height:1.2;
}

h3 {
	font-size: 1.75rem;
	line-height:1.2;
}

h4 {
	font-size: 1.5rem;
	line-height:1.2;
}

h5 {
	font-size: 1.25rem;
	line-height:1.2;
}

h6 {
	font-size: 1rem;
	line-height:1.2;
}

/* Template Styles */

.amp-wp-content,
.amp-wp-title-bar div {
	<?php if ( $content_max_width > 0 ) : ?>
	margin: 0 auto;
	max-width: <?php echo sprintf( '%dpx', $content_max_width ); ?>;
	<?php endif; ?>
}

html {
	background: <?php echo sanitize_hex_color( $header_background_color ); ?>;
}

body {
	background: <?php echo sanitize_hex_color( $theme_color ); ?>;
	color: <?php echo sanitize_hex_color( $text_color ); ?>;
	<!-- font-family: Georgia, 'Times New Roman', Times, Serif; -->
	font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", Helvetica, Arial, sans-serif;
	font-weight: 300;
	line-height: 1.75em;
}

p,
ol,
ul,
figure {
	margin: 0 0 1em;
	padding: 0;
}

a,
a:visited {
	color: <?php echo sanitize_hex_color( $link_color ); ?>;
}

a:hover,
a:active,
a:focus {
	color: <?php echo sanitize_hex_color( $text_color ); ?>;
}

/* Quotes */

blockquote,
.wp-block-quote.is-style-large {
	color: <?php echo sanitize_hex_color( $text_color ); ?>;
	background: rgba(127,127,127,.125);
	border-<?php echo is_rtl() ? 'right' : 'left'; ?>: 4px solid <?php echo sanitize_hex_color( $link_color ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>;
	margin: 8px 0 24px 0;
	padding: 16px;
}

blockquote p:last-child {
	margin-bottom: 0;
}

/* UI Fonts */

.amp-wp-meta,
.amp-wp-header div,
.amp-wp-title,
.wp-caption-text,
.amp-wp-tax-category,
.amp-wp-tax-tag,
.amp-wp-comments-link,
.amp-wp-footer p,
.back-to-top {
	font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen-Sans", "Ubuntu", "Cantarell", "Helvetica Neue", sans-serif;
}

/* Header */

.amp-wp-header {
	background-color: <?php echo sanitize_hex_color( $header_background_color ); ?>;
	box-shadow: 0 0 15px rgba(0,0,0,0.1);
}

.amp-wp-header > div {
	color: <?php echo sanitize_hex_color( $header_color ); ?>;
	font-size: 1em;
	font-weight: 400;
	margin: 0 auto;
	max-width: calc(840px - 32px);
	padding: 1rem 16px;
	position: relative;
	display:flex;
	justify-content: space-between;
	align-items:center;
	line-height:normal;
}

.amp-wp-header a {
	color: <?php echo sanitize_hex_color( $header_color ); ?>;
	text-decoration: none;
	display:inline-block;
}
.amp-wp-header img {
	display:block;
}
.amp-wp-header .faux-heading {
	line-height:1;
}
.amp-wp-header .site-title {
	font-size:1.5rem;
	font-weight:600;
}
.site-logo {
	max-width:<?php echo esc_attr( $logo_width ); ?>px;
	margin-left:auto;
	margin-right:auto;
}
@media ( max-width:540px) {
	.site-logo {
		max-width:<?php echo esc_attr( $logo_width_small ); ?>px;
	}
}

.amp-wp-header .amp-wp-site-icon {
	/** site icon is 32px **/
	background-color: <?php echo sanitize_hex_color( $header_color ); ?>;
	border: 1px solid <?php echo sanitize_hex_color( $header_color ); ?>;
	border-radius: 50%;
	position: absolute;
	<?php echo is_rtl() ? 'left' : 'right'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>: 18px;
	top: 10px;
}

/* Article */

.amp-wp-article {
	color: <?php echo sanitize_hex_color( $text_color ); ?>;
	font-weight: 400;
	margin: 1.5em auto;
	max-width: 840px;
	overflow-wrap: break-word;
	word-wrap: break-word;
	display:flex;
	flex-direction:column;
}
@media (max-width:540px) {
	.amp-wp-article {
		margin-top:0;
	}
}

/* Article Header */

.amp-wp-article-header {
	align-items: center;
	align-content: stretch;
	display: flex;
	flex-wrap: wrap;
	justify-content: space-between;
	margin: 0.5em 16px 0;
}

.amp-wp-title {
	color: <?php echo sanitize_hex_color( $black ); ?>;
	display: block;
	flex: 1 0 100%;
	font-weight: 700;
	margin: 0.5em 0 .725em;
	width: 100%;
	letter-spacing: -0.5px;
}
@media (max-width:480px) {
	h1 {
		font-size: 2rem;
	}
}
/* Article Meta */

.amp-wp-meta {
	color: <?php echo sanitize_hex_color( $muted_text_color ); ?>;
	display: inline-block;
	font-size: .875em;
	line-height: 1.5em;
	margin: 0 0.3125rem 1.5em 0;
	padding: 0;
}

.amp-wp-article-header .amp-wp-meta:last-of-type {
	text-align: <?php echo is_rtl() ? 'left' : 'right'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>;
	margin-right:auto;
}
.amp-wp-article-header .amp-wp-meta:first-of-type::after {
	content: "\00B7";
	color: #cfd0d2;
	margin-left: 0.3125rem;
}

.amp-wp-article-header .amp-wp-meta:first-of-type {
	text-align: <?php echo is_rtl() ? 'right' : 'left'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>;
}

.amp-wp-byline amp-img,
.amp-wp-byline .amp-wp-author {
	display: inline-block;
	vertical-align: middle;
}

.amp-wp-byline amp-img {
	border: 1px solid <?php echo sanitize_hex_color( $link_color ); ?>;
	border-radius: 50%;
	position: relative;
	margin-<?php echo is_rtl() ? 'left' : 'right'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>: 6px;
}

.amp-wp-posted-on {
	text-align: <?php echo is_rtl() ? 'left' : 'right'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>;
}

/* Featured image */

.amp-wp-article-featured-image {
	margin: 0 16px 0;
	order: -1;
}
.amp-wp-article-featured-image amp-img {
	margin: 0 auto;
}
.amp-wp-article-featured-image.wp-caption .wp-caption-text {
	margin: 0;
	padding-left:0;
	padding-right:0;
}
@media (max-width:540px) {
	.amp-wp-article-featured-image {
		margin: 0 0 0;
	}
	.amp-wp-article-featured-image.wp-caption .wp-caption-text {
		padding-left:16px;
		padding-right:16px;
	}
}
/* Article Content */

.amp-wp-article-content {
	margin: 0 16px;
}

.amp-wp-article-content ul,
.amp-wp-article-content ol {
	margin-<?php echo is_rtl() ? 'right' : 'left'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>: 2em;
	margin-top: 1em;
	margin-bottom: 1em;
}

.amp-wp-article-content .wp-caption {
	max-width: 100%;
}

.amp-wp-article-content amp-img {
	margin: 0 auto;
}

.amp-wp-article-content amp-img.alignright,
.amp-wp-article-content .wp-block-cover.alignright {
	margin: 0 0 1em 16px;
}

.amp-wp-article-content amp-img.alignleft,
.amp-wp-article-content .wp-block-cover.alignleft {
	margin: 0 16px 1em 0;
}

/* Captions */

.wp-caption {
	padding: 0;
}

.wp-caption.alignleft {
	margin-right: 16px;
}

.wp-caption.alignright {
	margin-left: 16px;
}

.wp-caption .wp-caption-text,
.blocks-gallery-caption {
	color: <?php echo sanitize_hex_color( $muted_text_color ); ?>;
	font-size: 0.75rem;
	line-height: 1.5em;
	margin: 0;
	padding: .66em 10px .75em;
}

/* AMP Media */

.alignwide,
.alignfull {
	clear: both;
}

amp-carousel {
	background: <?php echo sanitize_hex_color( $border_color ); ?>;
	margin: 0 0 1.5em;
}
amp-iframe,
amp-youtube,
amp-instagram,
amp-vine {
	background: <?php echo sanitize_hex_color( $border_color ); ?>;
	margin: 0 -16px 1.5em;
}

.amp-wp-article-content amp-carousel amp-img {
	border: none;
}

amp-carousel > amp-img > img {
	object-fit: contain;
}

.amp-wp-iframe-placeholder {
	background: <?php echo sanitize_hex_color( $border_color ); ?> url( <?php echo esc_url( $this->get( 'placeholder_image_url' ) ); ?> ) no-repeat center 40%;
	background-size: 48px 48px;
	min-height: 48px;
}

/* Article Footer Meta */

.amp-wp-article-footer .amp-wp-meta {
	display: block;
}

.amp-wp-tax-category,
.amp-wp-tax-tag {
	color: <?php echo sanitize_hex_color( $muted_text_color ); ?>;
	font-size: .875em;
	line-height: 1.5em;
	margin: 1.5em 16px;
}
.amp-wp-tax-category a,
.amp-wp-tax-tag a {
	color: <?php echo sanitize_hex_color( $black ); ?>;
}
.amp-wp-comments-link {
	color: <?php echo sanitize_hex_color( $muted_text_color ); ?>;
	font-size: .875em;
	line-height: 1.5em;
	text-align: center;
	margin: 2.25em 0 1.5em;
}

.amp-wp-comments-link a {
	border-radius: 0;
	background-color: <?php echo sanitize_hex_color( $button_background); ?>;
	color: <?php echo sanitize_hex_color( $button_color); ?>;
	cursor: pointer;
	display: inline-block;
	font-size: 14px;
	font-weight: 600;
	line-height: 18px;
	margin: 0 auto;
	padding: 16px 32px;
	text-decoration: none;
	width: auto;
	-webkit-transition: background-color 0.2s ease;
			transition: background-color 0.2s ease;
}

/* AMP Footer */

.amp-wp-footer {
	margin: calc(3em - 1px) 0 0;
	background: <?php echo sanitize_hex_color( $footer_background ); ?>;
}

.amp-wp-footer > div {
	margin: 0 auto;
	max-width: calc(840px - 32px);
	padding: 3em 16px 2.25em;
	position: relative;
	text-align:center;
}

.amp-wp-footer h2 {
	font-size: 1.5em;
	line-height: 1.375em;
	margin: 0 0 .5em;
}

.amp-wp-footer p {
	color: <?php echo sanitize_hex_color( $muted_text_color ); ?>;
	font-size: .8em;
	line-height: 1.5em;
	margin: 0 85px 0 0;
}

.amp-wp-footer a {
	text-decoration: none;
	display:inline-block
}

.back-to-top {
	bottom: 2.8em;
	font-size: .8em;
	font-weight: 600;
	line-height: 2em;
	<!-- position: absolute; -->
	<?php echo is_rtl() ? 'left' : 'right'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>: 16px;
}
/* Custom Theme AMP */
.amp-wp-header button {
	border:0;
	background:none;
	padding:0;
}
.amp-menu {
	display:block;
	width:18px;
	height:9px;
	border-top: 3px solid <?php echo sanitize_hex_color( $header_toggle_color); ?>;
	border-bottom:3px solid <?php echo sanitize_hex_color( $header_toggle_color); ?>;
	font-size:0;
	position:relative;
}
.amp-menu::after {
	content:'';
	width:100%;
	height:3px;
	background-color: <?php echo sanitize_hex_color( $header_toggle_color); ?>;
	position:absolute;
	top:3px;
	left:0
}
.amp-toggle-search {
	width:19px;
	height:22px;
	display:block;
	font-size:0;
	background-image: url("data:image/svg+xml,%3Csvg fill='none' fill-rule='evenodd' stroke='black' stroke-width='0.501' stroke-linejoin='bevel' stroke-miterlimit='10' font-family='Times New Roman' font-size='16' style='font-variant-ligatures:none' xmlns:xlink='http://www.w3.org/1999/xlink' xmlns='http://www.w3.org/2000/svg' version='1.1' overflow='visible' width='72.136pt' height='72.134pt' viewBox='269.74 -630.016 72.136 72.134'%3E%3Cdefs%3E%3C/defs%3E%3Cg id='Layer 1' transform='scale(1 -1)'%3E%3Cpath d='M 331.844,559.563 L 316.697,574.355 C 304.935,566.619 288.957,567.922 278.615,578.265 C 266.782,590.099 266.782,609.307 278.615,621.142 C 290.449,632.974 309.658,632.974 321.492,621.142 C 331.956,610.675 333.166,594.44 325.12,582.64 L 340.098,568.011 C 342.43,565.735 342.473,561.992 340.195,559.66 C 337.919,557.328 334.176,557.285 331.844,559.563 Z M 313.519,586.238 C 320.951,593.668 320.951,605.738 313.519,613.169 C 306.089,620.6 294.018,620.6 286.588,613.169 C 279.156,605.738 279.156,593.668 286.588,586.238 C 294.018,578.806 306.089,578.806 313.519,586.238 Z' fill='<?php echo esc_attr( str_replace('#', '%23', $header_toggle_color ) ); ?>' stroke-width='0.716' fill-rule='evenodd' stroke='none' marker-start='none' marker-end='none'/%3E%3C/g%3E%3C/svg%3E");
	background-repeat: no-repeat;
	background-position-x: 0;
	background-position-y: 0;
	background-size: 19px;
}
.amp-close-sidebar {
	width:16px;
	height:16px;
	display:block;
	font-size:0;
	background-image: url("data:image/svg+xml,%3Csvg fill='none' fill-rule='evenodd' stroke='black' stroke-width='0.501' stroke-linejoin='bevel' stroke-miterlimit='10' font-family='Times New Roman' font-size='16' style='font-variant-ligatures:none' xmlns:xlink='http://www.w3.org/1999/xlink' xmlns='http://www.w3.org/2000/svg' version='1.1' overflow='visible' width='53.459pt' height='53.459pt' viewBox='462.121 -623.463 53.459 53.459'%3E%3Cdefs%3E%3C/defs%3E%3Cg id='Layer 1' transform='scale(1 -1)'%3E%3Cpath d='M 470.076,570.004 L 462.121,577.959 L 480.896,596.733 L 462.121,615.509 L 470.076,623.463 L 488.85,604.688 L 507.626,623.463 L 515.58,615.509 L 496.805,596.733 L 515.58,577.959 L 507.626,570.004 L 488.85,588.779 L 470.076,570.004 Z' fill='<?php echo esc_attr( str_replace('#', '%23', $toggle_sidebar_menu_color ) ); ?>' stroke='none' stroke-width='0.5' fill-rule='evenodd' marker-start='none' marker-end='none'/%3E%3C/g%3E%3C/svg%3E%0A");
	background-repeat: no-repeat;
	background-position-x: 0;
	background-position-y: 0;
	background-size: 16px;
}
.no-toggle {
	display:block;
	width:19px;
	height:19px;
}
amp-sidebar {
	width:100%;
	max-width:380px;
	background: <?php echo sanitize_hex_color( $toggle_sidebar_background ); ?>;
	box-shadow: 0 5px 15px rgba(0,0,0,0.1);
}
.amp-sidebar-mask {
  background-color: rgba(255,255,255,0.86);
}
.toggle-sidebar > * {
	margin: 1.875rem;
}
amp-sidebar .site-logo.faux-heading {
	margin:0.5rem 0;
}
amp-sidebar .site-logo img {
	display:block;
}
.toggle-sidebar-header {
  display: flex;
  justify-content: space-between;
  align-items: center;
  border-bottom: 1px solid rgba(0,0,0,0.05);
  margin: 0;
  padding-left: 1.875rem;
  padding-right: 1.875rem;
  padding-top: 0.8125rem;
  padding-bottom: 0.8125rem;
}
.toggle-sidebar .close-sidebar {
  display: block;
  text-align: right;
  position: relative;
  font-size: 0.875rem;
  margin-left: auto;
}
.search-sidebar button {
	display:none;
}
.search-sidebar input[type="search"] {
	background-image: url("data:image/svg+xml,%3Csvg fill='none' fill-rule='evenodd' stroke='black' stroke-width='0.501' stroke-linejoin='bevel' stroke-miterlimit='10' font-family='Times New Roman' font-size='16' style='font-variant-ligatures:none' xmlns:xlink='http://www.w3.org/1999/xlink' xmlns='http://www.w3.org/2000/svg' version='1.1' overflow='visible' width='72.136pt' height='72.134pt' viewBox='269.74 -630.016 72.136 72.134'%3E%3Cdefs%3E%3C/defs%3E%3Cg id='Layer 1' transform='scale(1 -1)'%3E%3Cpath d='M 331.844,559.563 L 316.697,574.355 C 304.935,566.619 288.957,567.922 278.615,578.265 C 266.782,590.099 266.782,609.307 278.615,621.142 C 290.449,632.974 309.658,632.974 321.492,621.142 C 331.956,610.675 333.166,594.44 325.12,582.64 L 340.098,568.011 C 342.43,565.735 342.473,561.992 340.195,559.66 C 337.919,557.328 334.176,557.285 331.844,559.563 Z M 313.519,586.238 C 320.951,593.668 320.951,605.738 313.519,613.169 C 306.089,620.6 294.018,620.6 286.588,613.169 C 279.156,605.738 279.156,593.668 286.588,586.238 C 294.018,578.806 306.089,578.806 313.519,586.238 Z' fill='%2394979e' stroke-width='0.716' fill-rule='evenodd' stroke='none' marker-start='none' marker-end='none'/%3E%3C/g%3E%3C/svg%3E");
	background-repeat: no-repeat;
	background-position-x: 97%;
	background-position-y: 7px;
	background-size: 17px;
	border:1px solid #cfd0d2;
	padding:8px;
	width:100%;
}
/* Sidebar nav */
.primary-nav-sidebar {
  margin: 0;
  padding: 0;
  list-style: none;
}
.primary-nav-sidebar li {
  margin: 0;
  padding: 0;
  position: relative;
}
.primary-nav-sidebar a {
  padding: 0.5rem 0;
  display: inline-block;
  margin: 0;
  color: <?php echo sanitize_hex_color( $toggle_sidebar_menu_color ); ?>;
  text-decoration:none;
  font-weight:600;
}
.tfm-menu-sash span {
  color: <?php echo sanitize_hex_color( $white ); ?>;
  background-color: <?php echo sanitize_hex_color( $primary_theme_color); ?>;
  font-size: 0.625rem;
  padding: 0.25rem 0.375rem;
  margin-left: 5px;
  font-weight: 600;
  line-height: 1;
}
.post-categories-meta {
	margin: 0;
	padding: 0;
	list-style: none;
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	align-items: center;
	position: relative;
	font-size: 0.875rem;
}
.post-categories-meta li:not(:last-child)::after {
  content: ',';
  margin-right: 0.1875rem;
}
.entry-content.excerpt {
	color: <?php echo sanitize_hex_color( $muted_text_color); ?>;
	font-weight:600;
	margin: 0 16px 1.5rem 16px;
}
